## 0.17.7 (2022-02-24)

docutils: Add missing dunders to nodes.Element (#7377)

## 0.17.6 (2022-02-21)

Improve docutils stubs (#7256)

## 0.17.5 (2022-02-03)

Use `_typeshed.Self` in `docutils.VersionInfo` and `os.sched_param` (#7117)

## 0.17.4 (2022-01-08)

Use lowercase `type` everywhere (#6853)

## 0.17.2 (2021-12-28)

Use PEP 585 syntax wherever possible (#6717)

## 0.17.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

